@@ -22,50 +22,103 @@
 
 This AWS Solutions Construct implements an AWS CloudFront fronting an Amazon API Gateway REST API.
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition:
 
-```javascript
-import * as api from '@aws-cdk/aws-apigateway';
-import * as lambda from "@aws-cdk/aws-lambda";
+Typescript
+
+```python
+import { Construct } from 'constructs';
+import { Stack, StackProps } from 'aws-cdk-lib';
 import { CloudFrontToApiGateway } from '@aws-solutions-constructs/aws-cloudfront-apigateway';
+import * as lambda from 'aws-cdk-lib/aws-lambda';
+import * as api from 'aws-cdk-lib/aws-apigateway';
 
 const lambdaProps: lambda.FunctionProps = {
-    code: lambda.Code.fromAsset(`${__dirname}/lambda`),
-    runtime: lambda.Runtime.NODEJS_14_X,
-    handler: 'index.handler'
+  code: lambda.Code.fromAsset(`lambda`),
+  runtime: lambda.Runtime.NODEJS_14_X,
+  handler: 'index.handler'
 };
 
 const lambdafunction = new lambda.Function(this, 'LambdaFunction', lambdaProps);
 
 const apiGatewayProps: api.LambdaRestApiProps = {
-        handler: lambdafunction,
-        endpointConfiguration: {
-            types: [api.EndpointType.REGIONAL]
-        },
-        defaultMethodOptions: {
-            authorizationType: api.AuthorizationType.NONE
-        }
+  handler: lambdafunction,
+  endpointConfiguration: {
+    types: [api.EndpointType.REGIONAL]
+  },
+  defaultMethodOptions: {
+    authorizationType: api.AuthorizationType.NONE
+  }
 };
 
 const apiGateway = new api.LambdaRestApi(this, 'LambdaRestApi', apiGatewayProps);
 
 new CloudFrontToApiGateway(this, 'test-cloudfront-apigateway', {
-    existingApiGatewayObj: apiGateway
+  existingApiGatewayObj: apiGateway
 });
-
 ```
 
-## Initializer
+Python
 
-```text
-new CloudFrontToApiGateway(scope: Construct, id: string, props: CloudFrontToApiGatewayProps);
+```python
+from aws_solutions_constructs.aws_cloudfront_apigateway import CloudFrontToApiGateway
+from aws_cdk import (
+    aws_lambda as _lambda,
+    aws_apigateway as api,
+    Stack
+)
+from constructs import Construct
+
+lambda_function = _lambda.Function(self, 'LambdaFunction',
+                                    code=_lambda.Code.from_asset(
+                                        'lambda'),
+                                    runtime=_lambda.Runtime.PYTHON_3_9,
+                                    handler='index.handler')
+
+api_gateway = api.LambdaRestApi(self, 'LambdaRestApi',
+                                handler=lambda_function,
+                                endpoint_configuration=api.EndpointConfiguration(
+                                    types=[api.EndpointType.REGIONAL]
+                                ),
+                                default_method_options=api.MethodOptions(
+                                    authorization_type=api.AuthorizationType.NONE
+                                ))
+
+CloudFrontToApiGateway(self, 'test-cloudfront-apigateway',
+                        existing_api_gateway_obj=api_gateway
+                        )
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`CloudFrontToApiGatewayProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+import java.util.List;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awscdk.services.lambda.*;
+import software.amazon.awscdk.services.lambda.Runtime;
+import software.amazon.awscdk.services.apigateway.*;
+import software.amazon.awsconstructs.services.cloudfrontapigateway.*;
+
+final Function lambdaFunction = Function.Builder.create(this, "IndexHandler")
+        .runtime(Runtime.NODEJS_14_X)
+        .code(Code.fromAsset("lambda"))
+        .handler("index.handler")
+        .build();
+
+final LambdaRestApi apiGateway = LambdaRestApi.Builder.create(this, "myapi")
+        .handler(lambdaFunction)
+        .endpointConfiguration(new EndpointConfiguration.Builder()
+                .types(List.of(EndpointType.REGIONAL))
+                .build())
+        .build();
+
+new CloudFrontToApiGateway(this, "test-cloudfront-apigateway", new CloudFrontToApiGatewayProps.Builder()
+        .existingApiGatewayObj(apiGateway)
+        .build());
+```
 
 ## Pattern Construct Props
 
